pub fn init_port(port: u16) -> Result<u16, InitError>Expand description
Initialise the vlogger with a custom port and otherwise default configuation. If the custom port is set to 0, a free port will be choosen by the OS and returned by this function. This function never panics.
Vlog messages will not be filtered.
The RUST_VLOG environment variable is not used.