pub fn wait_for_connection()Expand description
Wait for a client to connect to the vlogging server. This blocks indefinitely if no server has been started.
pub fn wait_for_connection()Wait for a client to connect to the vlogging server. This blocks indefinitely if no server has been started.