wait_for_disconnect_timeout

Function wait_for_disconnect_timeout 

pub fn wait_for_disconnect_timeout(dur: Duration) -> bool
Wait for the client to disconnect from the vlogging server.

Returns true on success and false if it timed out.