pub fn init() -> u16Expand description
Initialise the vlogger with the default configuation.
The target whitelist gets loaded from the environment variable
RUST_VLOG. If it is not set, all targets are whitelisted.
Returns the port at which the server is made available.
Panics
This function will panic if the vlogger has already been
set or the server could not be started. For a non panicking
version see init_port.